# Generated by roxygen2: do not edit by hand

S3method(ascentDetails,latexgrob)
S3method(descentDetails,latexgrob)
S3method(editDetails,latexgrob)
S3method(heightDetails,gridmicrotex_labels)
S3method(heightDetails,latexgrob)
S3method(heightDetails,markdownbox)
S3method(makeContent,latexgrob)
S3method(makeContent,markdownbox)
S3method(print,gridmicrotex_markdown_style)
S3method(print,gridmicrotex_md_style)
S3method(print,latex_tree)
S3method(widthDetails,gridmicrotex_labels)
S3method(widthDetails,latexgrob)
S3method(widthDetails,markdownbox)
S3method(xDetails,latexgrob)
S3method(yDetails,latexgrob)
export(GeomLatex)
export(GeomMarkdown)
export(available_highlighters)
export(available_math_fonts)
export(check_fonts)
export(check_math_fonts)
export(clear_macros)
export(define_macro)
export(element_latex)
export(element_markdown)
export(geom_latex)
export(geom_markdown)
export(grid.latex)
export(grid.markdown)
export(grobMark)
export(latex_cache_clear)
export(latex_cache_info)
export(latex_cache_limit)
export(latex_dims)
export(latex_grob)
export(latex_options)
export(latex_tree)
export(latex_wrap)
export(list_macros)
export(load_font)
export(load_math_font)
export(markdown_box_grob)
export(markdown_grob)
export(markdown_style)
export(md_style)
export(register_highlighter)
export(reset_latex_options)
importFrom(Rcpp,sourceCpp)
importFrom(grid,ascentDetails)
importFrom(grid,descentDetails)
importFrom(grid,editDetails)
importFrom(grid,heightDetails)
importFrom(grid,makeContent)
importFrom(grid,widthDetails)
importFrom(grid,xDetails)
importFrom(grid,yDetails)
useDynLib(gridmicrotex, .registration = TRUE)
