# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

register_text_measurer <- function(fn) {
    invisible(.Call(`_gridmicrotex_register_text_measurer`, fn))
}

clear_text_measurer <- function() {
    invisible(.Call(`_gridmicrotex_clear_text_measurer`))
}

microtex_init <- function(clm_path, otf_path) {
    invisible(.Call(`_gridmicrotex_microtex_init`, clm_path, otf_path))
}

microtex_init_from_otf <- function(otf_path, index = 0L) {
    invisible(.Call(`_gridmicrotex_microtex_init_from_otf`, otf_path, index))
}

microtex_add_font <- function(clm_path, otf_path) {
    invisible(.Call(`_gridmicrotex_microtex_add_font`, clm_path, otf_path))
}

microtex_math_font_names <- function() {
    .Call(`_gridmicrotex_microtex_math_font_names`)
}

microtex_set_default_math_font <- function(name) {
    .Call(`_gridmicrotex_microtex_set_default_math_font`, name)
}

microtex_bidi_available <- function() {
    .Call(`_gridmicrotex_microtex_bidi_available`)
}

microtex_release <- function() {
    invisible(.Call(`_gridmicrotex_microtex_release`))
}

microtex_is_inited <- function() {
    .Call(`_gridmicrotex_microtex_is_inited`)
}

microtex_version <- function() {
    .Call(`_gridmicrotex_microtex_version`)
}

microtex_set_default_main_font <- function(family) {
    .Call(`_gridmicrotex_microtex_set_default_main_font`, family)
}

microtex_main_font_families <- function() {
    .Call(`_gridmicrotex_microtex_main_font_families`)
}

ot_math_table_bytes <- function(path, index = 0L) {
    .Call(`_gridmicrotex_ot_math_table_bytes`, path, index)
}

otf_to_clm_bytes <- function(path, index = 0L) {
    .Call(`_gridmicrotex_otf_to_clm_bytes`, path, index)
}

microtex_add_font_from_otf <- function(otf_path, index = 0L) {
    .Call(`_gridmicrotex_microtex_add_font_from_otf`, otf_path, index)
}

parse_latex_cpp <- function(tex, text_size = 20.0, line_space = 10.0, fg_color = "#000000", max_width = 0, math_font = "", main_font = "", use_path = TRUE, tex_style = "", justify = FALSE, optimal_break = FALSE) {
    .Call(`_gridmicrotex_parse_latex_cpp`, tex, text_size, line_space, fg_color, max_width, math_font, main_font, use_path, tex_style, justify, optimal_break)
}

