% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid-builder.R
\name{.resolve_text_face}
\alias{.resolve_text_face}
\title{Resolve MicroTeX FontStyle bitmask to R font face}
\usage{
.resolve_text_face(style)
}
\arguments{
\item{style}{Integer font style bitmask.}
}
\value{
Character: \code{"plain"}, \code{"bold"}, \code{"italic"},
or \code{"bold.italic"}.
}
\description{
MicroTeX FontStyle: rm=1, bf=2, it=4, etc. (bitmask).
}
\keyword{internal}
