% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid-builder.R
\name{cubic_bezier}
\alias{cubic_bezier}
\title{Approximate a cubic bezier curve with line segments}
\usage{
cubic_bezier(x0, y0, x1, y1, x2, y2, x3, y3, n = 16)
}
\description{
Approximate a cubic bezier curve with line segments
}
\keyword{internal}
