% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/deprecated.R
\name{gridmicrotex-deprecated}
\alias{gridmicrotex-deprecated}
\alias{load_font}
\alias{check_fonts}
\title{Deprecated functions}
\usage{
load_font(otf_path)

check_fonts()
}
\arguments{
\item{otf_path}{Path to the OTF/TTF font file.}
}
\value{
As the replacement function.
}
\description{
These functions still work but will be removed in a future release.
Both were renamed to say what they actually operate on: only
\strong{math} fonts (those carrying an OpenType MATH table) are ever
registered with MicroTeX. Text fonts need no loading --- they are
resolved on demand by \pkg{systemfonts} from \code{gp$fontfamily}.
}
\details{
\tabular{ll}{
\strong{Deprecated}  \tab \strong{Use instead} \cr
\code{load_font()}   \tab \code{\link{load_math_font}()}  \cr
\code{check_fonts()} \tab \code{\link{check_math_fonts}()} \cr
}
}
\keyword{internal}
