% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/units.R
\name{bigpt_to_tex_pt}
\alias{bigpt_to_tex_pt}
\title{Convert big points to TeX points}
\usage{
bigpt_to_tex_pt(big_pt)
}
\arguments{
\item{big_pt}{Numeric value in PostScript points.}
}
\value{
Numeric value in TeX points.
}
\description{
Convert big points to TeX points
}
\keyword{internal}
