% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gridmicrotex-package.R
\docType{package}
\name{gridmicrotex-package}
\alias{gridmicrotex}
\alias{gridmicrotex-package}
\title{gridmicrotex: Native 'LaTeX' Math Rendering for Grid Graphics}
\description{
Renders 'LaTeX' math equations as native R grid graphics objects (grobs) using the 'MicroTeX' 'C++' library as the layout engine. Produces resolution-independent vector output that works on any R graphics device, with no external 'LaTeX' installation required. Markdown labels and block documents that mix prose formatting with math are also rendered, for use with both 'grid' and 'ggplot2'.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/adayim/gridmicrotex}
  \item \url{https://adayim.github.io/gridmicrotex/}
  \item Report bugs at \url{https://github.com/adayim/gridmicrotex/issues}
}

}
\author{
\strong{Maintainer}: Alim Dayim \email{ad938@cam.ac.uk} (\href{https://orcid.org/0000-0001-9998-7463}{ORCID})

Other contributors:
\itemize{
  \item Nano Michael (Author of included 'MicroTeX' library) [copyright holder]
  \item  Bundled math font authors (See inst/COPYRIGHTS for the full list of authors of the bundled math fonts.) [copyright holder]
}

}
\keyword{internal}
