% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/units.R
\name{tex_pt_to_bigpt}
\alias{tex_pt_to_bigpt}
\title{Convert TeX points to big points}
\usage{
tex_pt_to_bigpt(tex_pt)
}
\arguments{
\item{tex_pt}{Numeric value in TeX points.}
}
\value{
Numeric value in big (PostScript) points.
}
\description{
TeX points (1/72.27 inch) differ from PostScript/big points (1/72 inch).
R's grid "bigpts" unit uses PostScript points.
}
\keyword{internal}
