% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid-builder.R
\name{build_path_grob}
\alias{build_path_grob}
\title{Convert path segments to a grid pathGrob}
\usage{
build_path_grob(path_data, col, idx, total_h)
}
\arguments{
\item{path_data}{List with \code{cmd} and \code{coords} elements.}

\item{col}{Fill color.}

\item{idx}{Index for naming.}

\item{total_h}{Total height for y-axis flipping.}
}
\value{
A \code{grid::pathGrob} or \code{NULL}.
}
\description{
Convert path segments to a grid pathGrob
}
\keyword{internal}
